@@ -24,9 +24,9 @@ from functools import reduce
 
 # Unimodal
 def rand(individual):
-    """Random test objective function.
+    r"""Random test objective function.
 
-    .. list-table:: 
+    .. list-table::
        :widths: 10 50
        :stub-columns: 1
 
@@ -37,14 +37,14 @@ def rand(individual):
        * - Global optima
          - none
        * - Function
-         - :math:`f(\mathbf{x}) = \\text{\\texttt{random}}(0,1)`
+         - :math:`f(\mathbf{x}) = \text{\texttt{random}}(0,1)`
     """
     return random.random(),
-    
-def plane(individual):
-    """Plane test objective function.
 
-    .. list-table:: 
+def plane(individual):
+    r"""Plane test objective function.
+
+    .. list-table::
        :widths: 10 50
        :stub-columns: 1
 
@@ -53,16 +53,16 @@ def plane(individual):
        * - Range
          - none
        * - Global optima
-         - :math:`x_i = 0, \\forall i \in \\lbrace 1 \\ldots N\\rbrace`, :math:`f(\mathbf{x}) = 0`
+         - :math:`x_i = 0, \forall i \in \lbrace 1 \ldots N\rbrace`, :math:`f(\mathbf{x}) = 0`
        * - Function
          - :math:`f(\mathbf{x}) = x_0`
     """
     return individual[0],
 
 def sphere(individual):
-    """Sphere test objective function.
+    r"""Sphere test objective function.
 
-    .. list-table:: 
+    .. list-table::
        :widths: 10 50
        :stub-columns: 1
 
@@ -71,16 +71,16 @@ def sphere(individual):
        * - Range
          - none
        * - Global optima
-         - :math:`x_i = 0, \\forall i \in \\lbrace 1 \\ldots N\\rbrace`, :math:`f(\mathbf{x}) = 0`
+         - :math:`x_i = 0, \forall i \in \lbrace 1 \ldots N\rbrace`, :math:`f(\mathbf{x}) = 0`
        * - Function
          - :math:`f(\mathbf{x}) = \sum_{i=1}^Nx_i^2`
     """
     return sum(gene * gene for gene in individual),
 
 def cigar(individual):
-    """Cigar test objective function.
-    
-    .. list-table:: 
+    r"""Cigar test objective function.
+
+    .. list-table::
        :widths: 10 50
        :stub-columns: 1
 
@@ -89,16 +89,16 @@ def cigar(individual):
        * - Range
          - none
        * - Global optima
-         - :math:`x_i = 0, \\forall i \in \\lbrace 1 \\ldots N\\rbrace`, :math:`f(\mathbf{x}) = 0`
+         - :math:`x_i = 0, \forall i \in \lbrace 1 \ldots N\rbrace`, :math:`f(\mathbf{x}) = 0`
        * - Function
-         - :math:`f(\mathbf{x}) = x_0^2 + 10^6\\sum_{i=1}^N\,x_i^2`
+         - :math:`f(\mathbf{x}) = x_0^2 + 10^6\sum_{i=1}^N\,x_i^2`
     """
-    return individual[0]**2 + 1e6 * sum(gene * gene for gene in individual),
+    return individual[0]**2 + 1e6 * sum(gene * gene for gene in individual[1:]),
 
-def rosenbrock(individual):  
-    """Rosenbrock test objective function.
+def rosenbrock(individual):
+    r"""Rosenbrock test objective function.
 
-    .. list-table:: 
+    .. list-table::
        :widths: 10 50
        :stub-columns: 1
 
@@ -107,10 +107,10 @@ def rosenbrock(individual):
        * - Range
          - none
        * - Global optima
-         - :math:`x_i = 1, \\forall i \in \\lbrace 1 \\ldots N\\rbrace`, :math:`f(\mathbf{x}) = 0`
+         - :math:`x_i = 1, \forall i \in \lbrace 1 \ldots N\rbrace`, :math:`f(\mathbf{x}) = 0`
        * - Function
-         - :math:`f(\\mathbf{x}) = \\sum_{i=1}^{N-1} (1-x_i)^2 + 100 (x_{i+1} - x_i^2 )^2`
-    
+         - :math:`f(\mathbf{x}) = \sum_{i=1}^{N-1} (1-x_i)^2 + 100 (x_{i+1} - x_i^2 )^2`
+
     .. plot:: code/benchmarks/rosenbrock.py
        :width: 67 %
     """
@@ -118,12 +118,12 @@ def rosenbrock(individual):
                    for x, y in zip(individual[:-1], individual[1:])),
 
 def h1(individual):
-    """ Simple two-dimensional function containing several local maxima.
-    From: The Merits of a Parallel Genetic Algorithm in Solving Hard 
-    Optimization Problems, A. J. Knoek van Soest and L. J. R. Richard 
+    r""" Simple two-dimensional function containing several local maxima.
+    From: The Merits of a Parallel Genetic Algorithm in Solving Hard
+    Optimization Problems, A. J. Knoek van Soest and L. J. R. Richard
     Casius, J. Biomech. Eng. 125, 141 (2003)
 
-    .. list-table:: 
+    .. list-table::
        :widths: 10 50
        :stub-columns: 1
 
@@ -134,8 +134,8 @@ def h1(individual):
        * - Global optima
          - :math:`\mathbf{x} = (8.6998, 6.7665)`, :math:`f(\mathbf{x}) = 2`\n
        * - Function
-         - :math:`f(\mathbf{x}) = \\frac{\sin(x_1 - \\frac{x_2}{8})^2 + \
-            \\sin(x_2 + \\frac{x_1}{8})^2}{\\sqrt{(x_1 - 8.6998)^2 + \
+         - :math:`f(\mathbf{x}) = \frac{\sin(x_1 - \frac{x_2}{8})^2 + \
+            \sin(x_2 + \frac{x_1}{8})^2}{\sqrt{(x_1 - 8.6998)^2 + \
             (x_2 - 6.7665)^2} + 1}`
 
     .. plot:: code/benchmarks/h1.py
@@ -145,12 +145,12 @@ def h1(individual):
     denum = ((individual[0] - 8.6998)**2 + (individual[1] - 6.7665)**2)**0.5 + 1
     return num / denum,
 
- # 
+ #
 # Multimodal
 def ackley(individual):
-    """Ackley test objective function.
+    r"""Ackley test objective function.
 
-    .. list-table:: 
+    .. list-table::
        :widths: 10 50
        :stub-columns: 1
 
@@ -159,22 +159,22 @@ def ackley(individual):
        * - Range
          - :math:`x_i \in [-15, 30]`
        * - Global optima
-         - :math:`x_i = 0, \\forall i \in \\lbrace 1 \\ldots N\\rbrace`, :math:`f(\mathbf{x}) = 0`
+         - :math:`x_i = 0, \forall i \in \lbrace 1 \ldots N\rbrace`, :math:`f(\mathbf{x}) = 0`
        * - Function
-         - :math:`f(\\mathbf{x}) = 20 - 20\exp\left(-0.2\sqrt{\\frac{1}{N} \
-            \\sum_{i=1}^N x_i^2} \\right) + e - \\exp\\left(\\frac{1}{N}\sum_{i=1}^N \\cos(2\pi x_i) \\right)`
-    
+         - :math:`f(\mathbf{x}) = 20 - 20\exp\left(-0.2\sqrt{\frac{1}{N} \
+            \sum_{i=1}^N x_i^2} \right) + e - \exp\left(\frac{1}{N}\sum_{i=1}^N \cos(2\pi x_i) \right)`
+
     .. plot:: code/benchmarks/ackley.py
        :width: 67 %
     """
     N = len(individual)
     return 20 - 20 * exp(-0.2*sqrt(1.0/N * sum(x**2 for x in individual))) \
             + e - exp(1.0/N * sum(cos(2*pi*x) for x in individual)),
-            
-def bohachevsky(individual):
-    """Bohachevsky test objective function.
 
-    .. list-table:: 
+def bohachevsky(individual):
+    r"""Bohachevsky test objective function.
+
+    .. list-table::
        :widths: 10 50
        :stub-columns: 1
 
@@ -183,21 +183,21 @@ def bohachevsky(individual):
        * - Range
          - :math:`x_i \in [-100, 100]`
        * - Global optima
-         - :math:`x_i = 0, \\forall i \in \\lbrace 1 \\ldots N\\rbrace`, :math:`f(\mathbf{x}) = 0`
+         - :math:`x_i = 0, \forall i \in \lbrace 1 \ldots N\rbrace`, :math:`f(\mathbf{x}) = 0`
        * - Function
          -  :math:`f(\mathbf{x}) = \sum_{i=1}^{N-1}(x_i^2 + 2x_{i+1}^2 - \
                    0.3\cos(3\pi x_i) - 0.4\cos(4\pi x_{i+1}) + 0.7)`
-    
+
     .. plot:: code/benchmarks/bohachevsky.py
        :width: 67 %
     """
-    return sum(x**2 + 2*x1**2 - 0.3*cos(3*pi*x) - 0.4*cos(4*pi*x1) + 0.7 
+    return sum(x**2 + 2*x1**2 - 0.3*cos(3*pi*x) - 0.4*cos(4*pi*x1) + 0.7
                 for x, x1 in zip(individual[:-1], individual[1:])),
 
 def griewank(individual):
-    """Griewank test objective function.
-    
-    .. list-table:: 
+    r"""Griewank test objective function.
+
+    .. list-table::
        :widths: 10 50
        :stub-columns: 1
 
@@ -206,21 +206,21 @@ def griewank(individual):
        * - Range
          - :math:`x_i \in [-600, 600]`
        * - Global optima
-         - :math:`x_i = 0, \\forall i \in \\lbrace 1 \\ldots N\\rbrace`, :math:`f(\mathbf{x}) = 0`
+         - :math:`x_i = 0, \forall i \in \lbrace 1 \ldots N\rbrace`, :math:`f(\mathbf{x}) = 0`
        * - Function
-         - :math:`f(\\mathbf{x}) = \\frac{1}{4000}\\sum_{i=1}^N\,x_i^2 - \
-                  \prod_{i=1}^N\\cos\\left(\\frac{x_i}{\sqrt{i}}\\right) + 1`
+         - :math:`f(\mathbf{x}) = \frac{1}{4000}\sum_{i=1}^N\,x_i^2 - \
+                  \prod_{i=1}^N\cos\left(\frac{x_i}{\sqrt{i}}\right) + 1`
 
     .. plot:: code/benchmarks/griewank.py
        :width: 67 %
     """
     return 1.0/4000.0 * sum(x**2 for x in individual) - \
         reduce(mul, (cos(x/sqrt(i+1.0)) for i, x in enumerate(individual)), 1) + 1,
-            
-def rastrigin(individual):
-    """Rastrigin test objective function.
 
-    .. list-table:: 
+def rastrigin(individual):
+    r"""Rastrigin test objective function.
+
+    .. list-table::
        :widths: 10 50
        :stub-columns: 1
 
@@ -229,45 +229,45 @@ def rastrigin(individual):
        * - Range
          - :math:`x_i \in [-5.12, 5.12]`
        * - Global optima
-         - :math:`x_i = 0, \\forall i \in \\lbrace 1 \\ldots N\\rbrace`, :math:`f(\mathbf{x}) = 0`
+         - :math:`x_i = 0, \forall i \in \lbrace 1 \ldots N\rbrace`, :math:`f(\mathbf{x}) = 0`
        * - Function
-         - :math:`f(\\mathbf{x}) = 10N + \sum_{i=1}^N x_i^2 - 10 \\cos(2\\pi x_i)`
+         - :math:`f(\mathbf{x}) = 10N + \sum_{i=1}^N x_i^2 - 10 \cos(2\pi x_i)`
 
     .. plot:: code/benchmarks/rastrigin.py
        :width: 67 %
-    """     
+    """
     return 10 * len(individual) + sum(gene * gene - 10 * \
                         cos(2 * pi * gene) for gene in individual),
 
 def rastrigin_scaled(individual):
-    """Scaled Rastrigin test objective function.
-    
-    :math:`f_{\\text{RastScaled}}(\mathbf{x}) = 10N + \sum_{i=1}^N \
-        \left(10^{\left(\\frac{i-1}{N-1}\\right)} x_i \\right)^2 x_i)^2 - \
-        10\cos\\left(2\\pi 10^{\left(\\frac{i-1}{N-1}\\right)} x_i \\right)`
+    r"""Scaled Rastrigin test objective function.
+
+    :math:`f_{\text{RastScaled}}(\mathbf{x}) = 10N + \sum_{i=1}^N \
+        \left(10^{\left(\frac{i-1}{N-1}\right)} x_i \right)^2 - \
+        10\cos\left(2\pi 10^{\left(\frac{i-1}{N-1}\right)} x_i \right)`
     """
     N = len(individual)
-    return 10*N + sum((10**(i/(N-1))*x)**2 - 
+    return 10*N + sum((10**(i/(N-1))*x)**2 -
                       10*cos(2*pi*10**(i/(N-1))*x) for i, x in enumerate(individual)),
 
 def rastrigin_skew(individual):
-    """Skewed Rastrigin test objective function.
-    
-     :math:`f_{\\text{RastSkew}}(\mathbf{x}) = 10N \sum_{i=1}^N \left(y_i^2 - 10 \\cos(2\\pi x_i)\\right)`
-        
-     :math:`\\text{with } y_i = \
-                            \\begin{cases} \
-                                10\\cdot x_i & \\text{ if } x_i > 0,\\\ \
-                                x_i & \\text{ otherwise } \
-                            \\end{cases}`
+    r"""Skewed Rastrigin test objective function.
+
+     :math:`f_{\text{RastSkew}}(\mathbf{x}) = 10N + \sum_{i=1}^N \left(y_i^2 - 10 \cos(2\pi x_i)\right)`
+
+     :math:`\text{with } y_i = \
+                            \begin{cases} \
+                                10\cdot x_i & \text{ if } x_i > 0,\\ \
+                                x_i & \text{ otherwise } \
+                            \end{cases}`
     """
     N = len(individual)
-    return 10*N + sum((10*x if x > 0 else x)**2 
+    return 10*N + sum((10*x if x > 0 else x)**2
                     - 10*cos(2*pi*(10*x if x > 0 else x)) for x in individual),
 def schaffer(individual):
-    """Schaffer test objective function.
-    
-    .. list-table:: 
+    r"""Schaffer test objective function.
+
+    .. list-table::
        :widths: 10 50
        :stub-columns: 1
 
@@ -276,22 +276,22 @@ def schaffer(individual):
        * - Range
          - :math:`x_i \in [-100, 100]`
        * - Global optima
-         - :math:`x_i = 0, \\forall i \in \\lbrace 1 \\ldots N\\rbrace`, :math:`f(\mathbf{x}) = 0`
+         - :math:`x_i = 0, \forall i \in \lbrace 1 \ldots N\rbrace`, :math:`f(\mathbf{x}) = 0`
        * - Function
          -  :math:`f(\mathbf{x}) = \sum_{i=1}^{N-1} (x_i^2+x_{i+1}^2)^{0.25} \cdot \
-                  \\left[ \sin^2(50\cdot(x_i^2+x_{i+1}^2)^{0.10}) + 1.0 \
-                  \\right]`
+                  \left[ \sin^2(50\cdot(x_i^2+x_{i+1}^2)^{0.10}) + 1.0 \
+                  \right]`
 
     .. plot:: code/benchmarks/schaffer.py
         :width: 67 %
     """
-    return sum((x**2+x1**2)**0.25 * ((sin(50*(x**2+x1**2)**0.1))**2+1.0) 
+    return sum((x**2+x1**2)**0.25 * ((sin(50*(x**2+x1**2)**0.1))**2+1.0)
                 for x, x1 in zip(individual[:-1], individual[1:])),
 
 def schwefel(individual):
-    """Schwefel test objective function.
+    r"""Schwefel test objective function.
 
-    .. list-table:: 
+    .. list-table::
        :widths: 10 50
        :stub-columns: 1
 
@@ -300,23 +300,23 @@ def schwefel(individual):
        * - Range
          - :math:`x_i \in [-500, 500]`
        * - Global optima
-         - :math:`x_i = 420.96874636, \\forall i \in \\lbrace 1 \\ldots N\\rbrace`, :math:`f(\mathbf{x}) = 0`
+         - :math:`x_i = 420.96874636, \forall i \in \lbrace 1 \ldots N\rbrace`, :math:`f(\mathbf{x}) = 0`
        * - Function
          - :math:`f(\mathbf{x}) = 418.9828872724339\cdot N - \
-            \sum_{i=1}^N\,x_i\sin\\left(\sqrt{|x_i|}\\right)`
+            \sum_{i=1}^N\,x_i\sin\left(\sqrt{|x_i|}\right)`
 
 
     .. plot:: code/benchmarks/schwefel.py
         :width: 67 %
-    """    
+    """
     N = len(individual)
     return 418.9828872724339*N-sum(x*sin(sqrt(abs(x))) for x in individual),
 
 def himmelblau(individual):
-    """The Himmelblau's function is multimodal with 4 defined minimums in 
+    r"""The Himmelblau's function is multimodal with 4 defined minimums in
     :math:`[-6, 6]^2`.
 
-    .. list-table:: 
+    .. list-table::
        :widths: 10 50
        :stub-columns: 1
 
@@ -339,22 +339,22 @@ def himmelblau(individual):
         (individual[0] + individual[1] * individual[1] - 7)**2,
 
 def shekel(individual, a, c):
-    """The Shekel multimodal function can have any number of maxima. The number
+    r"""The Shekel multimodal function can have any number of maxima. The number
     of maxima is given by the length of any of the arguments *a* or *c*, *a*
-    is a matrix of size :math:`M\\times N`, where *M* is the number of maxima
-    and *N* the number of dimensions and *c* is a :math:`M\\times 1` vector.
-    
-    :math:`f_\\text{Shekel}(\mathbf{x}) = \\sum_{i = 1}^{M} \\frac{1}{c_{i} + 
-    \\sum_{j = 1}^{N} (x_{j} - a_{ij})^2 }`
-    
+    is a matrix of size :math:`M\times N`, where *M* is the number of maxima
+    and *N* the number of dimensions and *c* is a :math:`M\times 1` vector.
+
+    :math:`f_\text{Shekel}(\mathbf{x}) = \sum_{i = 1}^{M} \frac{1}{c_{i} +
+    \sum_{j = 1}^{N} (x_{j} - a_{ij})^2 }`
+
     The following figure uses
-    
-    :math:`\\mathcal{A} = \\begin{bmatrix} 0.5 & 0.5 \\\\ 0.25 & 0.25 \\\\ 
-    0.25 & 0.75 \\\\ 0.75 & 0.25 \\\\ 0.75 & 0.75 \\end{bmatrix}` and
-    :math:`\\mathbf{c} = \\begin{bmatrix} 0.002 \\\\ 0.005 \\\\ 0.005
-    \\\\ 0.005 \\\\ 0.005 \\end{bmatrix}`, thus defining 5 maximums in
-    :math:`\\mathbb{R}^2`.
-    
+
+    :math:`\mathcal{A} = \begin{bmatrix} 0.5 & 0.5 \\ 0.25 & 0.25 \\
+    0.25 & 0.75 \\ 0.75 & 0.25 \\ 0.75 & 0.75 \end{bmatrix}` and
+    :math:`\mathbf{c} = \begin{bmatrix} 0.002 \\ 0.005 \\ 0.005
+    \\ 0.005 \\ 0.005 \end{bmatrix}`, thus defining 5 maximums in
+    :math:`\mathbb{R}^2`.
+
     .. plot:: code/benchmarks/shekel.py
         :width: 67 %
     """
@@ -362,11 +362,11 @@ def shekel(individual, a, c):
 
 # Multiobjectives
 def kursawe(individual):
-    """Kursawe multiobjective function.
-    
-    :math:`f_{\\text{Kursawe}1}(\\mathbf{x}) = \\sum_{i=1}^{N-1} -10 e^{-0.2 \\sqrt{x_i^2 + x_{i+1}^2} }`
-    
-    :math:`f_{\\text{Kursawe}2}(\\mathbf{x}) = \\sum_{i=1}^{N} |x_i|^{0.8} + 5 \\sin(x_i^3)`
+    r"""Kursawe multiobjective function.
+
+    :math:`f_{\text{Kursawe}1}(\mathbf{x}) = \sum_{i=1}^{N-1} -10 e^{-0.2 \sqrt{x_i^2 + x_{i+1}^2} }`
+
+    :math:`f_{\text{Kursawe}2}(\mathbf{x}) = \sum_{i=1}^{N} |x_i|^{0.8} + 5 \sin(x_i^3)`
 
     .. plot:: code/benchmarks/kursawe.py
        :width: 100 %
@@ -377,25 +377,25 @@ def kursawe(individual):
 
 
 def schaffer_mo(individual):
-    """Schaffer's multiobjective function on a one attribute *individual*.
+    r"""Schaffer's multiobjective function on a one attribute *individual*.
     From: J. D. Schaffer, "Multiple objective optimization with vector
     evaluated genetic algorithms", in Proceedings of the First International
-    Conference on Genetic Algorithms, 1987. 
-    
-    :math:`f_{\\text{Schaffer}1}(\\mathbf{x}) = x_1^2`
-    
-    :math:`f_{\\text{Schaffer}2}(\\mathbf{x}) = (x_1-2)^2`
+    Conference on Genetic Algorithms, 1987.
+
+    :math:`f_{\text{Schaffer}1}(\mathbf{x}) = x_1^2`
+
+    :math:`f_{\text{Schaffer}2}(\mathbf{x}) = (x_1-2)^2`
     """
     return individual[0] ** 2, (individual[0] - 2) ** 2
-    
+
 def zdt1(individual):
-    """ZDT1 multiobjective function.
-    
-    :math:`g(\\mathbf{x}) = 1 + \\frac{9}{n-1}\\sum_{i=2}^n x_i`
-    
-    :math:`f_{\\text{ZDT1}1}(\\mathbf{x}) = x_1`
-    
-    :math:`f_{\\text{ZDT1}2}(\\mathbf{x}) = g(\\mathbf{x})\\left[1 - \\sqrt{\\frac{x_1}{g(\\mathbf{x})}}\\right]`
+    r"""ZDT1 multiobjective function.
+
+    :math:`g(\mathbf{x}) = 1 + \frac{9}{n-1}\sum_{i=2}^n x_i`
+
+    :math:`f_{\text{ZDT1}1}(\mathbf{x}) = x_1`
+
+    :math:`f_{\text{ZDT1}2}(\mathbf{x}) = g(\mathbf{x})\left[1 - \sqrt{\frac{x_1}{g(\mathbf{x})}}\right]`
     """
     g  = 1.0 + 9.0*sum(individual[1:])/(len(individual)-1)
     f1 = individual[0]
@@ -403,29 +403,29 @@ def zdt1(individual):
     return f1, f2
 
 def zdt2(individual):
-    """ZDT2 multiobjective function.
-    
-    :math:`g(\\mathbf{x}) = 1 + \\frac{9}{n-1}\\sum_{i=2}^n x_i`
-    
-    :math:`f_{\\text{ZDT2}1}(\\mathbf{x}) = x_1`
-    
-    :math:`f_{\\text{ZDT2}2}(\\mathbf{x}) = g(\\mathbf{x})\\left[1 - \\left(\\frac{x_1}{g(\\mathbf{x})}\\right)^2\\right]`
-    
+    r"""ZDT2 multiobjective function.
+
+    :math:`g(\mathbf{x}) = 1 + \frac{9}{n-1}\sum_{i=2}^n x_i`
+
+    :math:`f_{\text{ZDT2}1}(\mathbf{x}) = x_1`
+
+    :math:`f_{\text{ZDT2}2}(\mathbf{x}) = g(\mathbf{x})\left[1 - \left(\frac{x_1}{g(\mathbf{x})}\right)^2\right]`
+
     """
 
     g  = 1.0 + 9.0*sum(individual[1:])/(len(individual)-1)
     f1 = individual[0]
     f2 = g * (1 - (f1/g)**2)
     return f1, f2
-    
+
 def zdt3(individual):
-    """ZDT3 multiobjective function.
+    r"""ZDT3 multiobjective function.
 
-    :math:`g(\\mathbf{x}) = 1 + \\frac{9}{n-1}\\sum_{i=2}^n x_i`
+    :math:`g(\mathbf{x}) = 1 + \frac{9}{n-1}\sum_{i=2}^n x_i`
 
-    :math:`f_{\\text{ZDT3}1}(\\mathbf{x}) = x_1`
+    :math:`f_{\text{ZDT3}1}(\mathbf{x}) = x_1`
 
-    :math:`f_{\\text{ZDT3}2}(\\mathbf{x}) = g(\\mathbf{x})\\left[1 - \\sqrt{\\frac{x_1}{g(\\mathbf{x})}} - \\frac{x_1}{g(\\mathbf{x})}\\sin(10\\pi x_1)\\right]`
+    :math:`f_{\text{ZDT3}2}(\mathbf{x}) = g(\mathbf{x})\left[1 - \sqrt{\frac{x_1}{g(\mathbf{x})}} - \frac{x_1}{g(\mathbf{x})}\sin(10\pi x_1)\right]`
 
     """
 
@@ -435,29 +435,29 @@ def zdt3(individual):
     return f1, f2
 
 def zdt4(individual):
-    """ZDT4 multiobjective function.
-    
-    :math:`g(\\mathbf{x}) = 1 + 10(n-1) + \\sum_{i=2}^n \\left[ x_i^2 - 10\\cos(4\\pi x_i) \\right]`
+    r"""ZDT4 multiobjective function.
+
+    :math:`g(\mathbf{x}) = 1 + 10(n-1) + \sum_{i=2}^n \left[ x_i^2 - 10\cos(4\pi x_i) \right]`
+
+    :math:`f_{\text{ZDT4}1}(\mathbf{x}) = x_1`
+
+    :math:`f_{\text{ZDT4}2}(\mathbf{x}) = g(\mathbf{x})\left[ 1 - \sqrt{x_1/g(\mathbf{x})} \right]`
 
-    :math:`f_{\\text{ZDT4}1}(\\mathbf{x}) = x_1`
-    
-    :math:`f_{\\text{ZDT4}2}(\\mathbf{x}) = g(\\mathbf{x})\\left[ 1 - \\sqrt{x_1/g(\\mathbf{x})} \\right]`
-    
     """
     g  = 1 + 10*(len(individual)-1) + sum(xi**2 - 10*cos(4*pi*xi) for xi in individual[1:])
     f1 = individual[0]
     f2 = g * (1 - sqrt(f1/g))
     return f1, f2
-    
+
 def zdt6(individual):
-    """ZDT6 multiobjective function.
-    
-    :math:`g(\\mathbf{x}) = 1 + 9 \\left[ \\left(\\sum_{i=2}^n x_i\\right)/(n-1) \\right]^{0.25}`
-    
-    :math:`f_{\\text{ZDT6}1}(\\mathbf{x}) = 1 - \\exp(-4x_1)\\sin^6(6\\pi x_1)`
-    
-    :math:`f_{\\text{ZDT6}2}(\\mathbf{x}) = g(\\mathbf{x}) \left[ 1 - (f_{\\text{ZDT6}1}(\\mathbf{x})/g(\\mathbf{x}))^2 \\right]`
-    
+    r"""ZDT6 multiobjective function.
+
+    :math:`g(\mathbf{x}) = 1 + 9 \left[ \left(\sum_{i=2}^n x_i\right)/(n-1) \right]^{0.25}`
+
+    :math:`f_{\text{ZDT6}1}(\mathbf{x}) = 1 - \exp(-4x_1)\sin^6(6\pi x_1)`
+
+    :math:`f_{\text{ZDT6}2}(\mathbf{x}) = g(\mathbf{x}) \left[ 1 - (f_{\text{ZDT6}1}(\mathbf{x})/g(\mathbf{x}))^2 \right]`
+
     """
     g  = 1 + 9 * (sum(individual[1:]) / (len(individual)-1))**0.25
     f1 = 1 - exp(-4*individual[0]) * sin(6*pi*individual[0])**6
@@ -465,51 +465,51 @@ def zdt6(individual):
     return f1, f2
 
 def dtlz1(individual, obj):
-    """DTLZ1 multiobjective function. It returns a tuple of *obj* values. 
+    r"""DTLZ1 multiobjective function. It returns a tuple of *obj* values.
     The individual must have at least *obj* elements.
-    From: K. Deb, L. Thiele, M. Laumanns and E. Zitzler. Scalable Multi-Objective 
+    From: K. Deb, L. Thiele, M. Laumanns and E. Zitzler. Scalable Multi-Objective
     Optimization Test Problems. CEC 2002, p. 825 - 830, IEEE Press, 2002.
 
-    :math:`g(\\mathbf{x}_m) = 100\\left(|\\mathbf{x}_m| + \sum_{x_i \in \\mathbf{x}_m}\\left((x_i - 0.5)^2 - \\cos(20\pi(x_i - 0.5))\\right)\\right)`
+    :math:`g(\mathbf{x}_m) = 100\left(|\mathbf{x}_m| + \sum_{x_i \in \mathbf{x}_m}\left((x_i - 0.5)^2 - \cos(20\pi(x_i - 0.5))\right)\right)`
 
-    :math:`f_{\\text{DTLZ1}1}(\\mathbf{x}) = \\frac{1}{2} (1 + g(\\mathbf{x}_m)) \\prod_{i=1}^{m-1}x_i`
-    
-    :math:`f_{\\text{DTLZ1}2}(\\mathbf{x}) = \\frac{1}{2} (1 + g(\\mathbf{x}_m)) (1-x_{m-1}) \\prod_{i=1}^{m-2}x_i`
-    
-    :math:`\\ldots`
-    
-    :math:`f_{\\text{DTLZ1}m-1}(\\mathbf{x}) = \\frac{1}{2} (1 + g(\\mathbf{x}_m)) (1 - x_2) x_1`
-    
-    :math:`f_{\\text{DTLZ1}m}(\\mathbf{x}) = \\frac{1}{2} (1 - x_1)(1 + g(\\mathbf{x}_m))`
-    
-    Where :math:`m` is the number of objectives and :math:`\\mathbf{x}_m` is a
-    vector of the remaining attributes :math:`[x_m~\\ldots~x_n]` of the
+    :math:`f_{\text{DTLZ1}1}(\mathbf{x}) = \frac{1}{2} (1 + g(\mathbf{x}_m)) \prod_{i=1}^{m-1}x_i`
+
+    :math:`f_{\text{DTLZ1}2}(\mathbf{x}) = \frac{1}{2} (1 + g(\mathbf{x}_m)) (1-x_{m-1}) \prod_{i=1}^{m-2}x_i`
+
+    :math:`\ldots`
+
+    :math:`f_{\text{DTLZ1}m-1}(\mathbf{x}) = \frac{1}{2} (1 + g(\mathbf{x}_m)) (1 - x_2) x_1`
+
+    :math:`f_{\text{DTLZ1}m}(\mathbf{x}) = \frac{1}{2} (1 - x_1)(1 + g(\mathbf{x}_m))`
+
+    Where :math:`m` is the number of objectives and :math:`\mathbf{x}_m` is a
+    vector of the remaining attributes :math:`[x_m~\ldots~x_n]` of the
     individual in :math:`n > m` dimensions.
-    
+
     """
     g = 100 * (len(individual[obj-1:]) + sum((xi-0.5)**2 - cos(20*pi*(xi-0.5)) for xi in individual[obj-1:]))
     f = [0.5 * reduce(mul, individual[:obj-1], 1) * (1 + g)]
-    f.extend(0.5 * reduce(mul, individual[:m], 1) * (1 - individual[m]) * (1 + g) for m in reversed(xrange(obj-1)))
+    f.extend(0.5 * reduce(mul, individual[:m], 1) * (1 - individual[m]) * (1 + g) for m in reversed(range(obj-1)))
     return f
 
 def dtlz2(individual, obj):
-    """DTLZ2 multiobjective function. It returns a tuple of *obj* values. 
+    r"""DTLZ2 multiobjective function. It returns a tuple of *obj* values.
     The individual must have at least *obj* elements.
-    From: K. Deb, L. Thiele, M. Laumanns and E. Zitzler. Scalable Multi-Objective 
+    From: K. Deb, L. Thiele, M. Laumanns and E. Zitzler. Scalable Multi-Objective
     Optimization Test Problems. CEC 2002, p. 825 - 830, IEEE Press, 2002.
-    
-    :math:`g(\\mathbf{x}_m) = \\sum_{x_i \in \\mathbf{x}_m} (x_i - 0.5)^2`
-    
-    :math:`f_{\\text{DTLZ2}1}(\\mathbf{x}) = (1 + g(\\mathbf{x}_m)) \\prod_{i=1}^{m-1} \\cos(0.5x_i\pi)`
-    
-    :math:`f_{\\text{DTLZ2}2}(\\mathbf{x}) = (1 + g(\\mathbf{x}_m)) \\sin(0.5x_{m-1}\pi ) \\prod_{i=1}^{m-2} \\cos(0.5x_i\pi)`
-    
-    :math:`\\ldots`
-    
-    :math:`f_{\\text{DTLZ2}m}(\\mathbf{x}) = (1 + g(\\mathbf{x}_m)) \\sin(0.5x_{1}\pi )`
-    
-    Where :math:`m` is the number of objectives and :math:`\\mathbf{x}_m` is a
-    vector of the remaining attributes :math:`[x_m~\\ldots~x_n]` of the
+
+    :math:`g(\mathbf{x}_m) = \sum_{x_i \in \mathbf{x}_m} (x_i - 0.5)^2`
+
+    :math:`f_{\text{DTLZ2}1}(\mathbf{x}) = (1 + g(\mathbf{x}_m)) \prod_{i=1}^{m-1} \cos(0.5x_i\pi)`
+
+    :math:`f_{\text{DTLZ2}2}(\mathbf{x}) = (1 + g(\mathbf{x}_m)) \sin(0.5x_{m-1}\pi ) \prod_{i=1}^{m-2} \cos(0.5x_i\pi)`
+
+    :math:`\ldots`
+
+    :math:`f_{\text{DTLZ2}m}(\mathbf{x}) = (1 + g(\mathbf{x}_m)) \sin(0.5x_{1}\pi )`
+
+    Where :math:`m` is the number of objectives and :math:`\mathbf{x}_m` is a
+    vector of the remaining attributes :math:`[x_m~\ldots~x_n]` of the
     individual in :math:`n > m` dimensions.
     """
     xc = individual[:obj-1]
@@ -521,23 +521,23 @@ def dtlz2(individual, obj):
     return f
 
 def dtlz3(individual, obj):
-    """DTLZ3 multiobjective function. It returns a tuple of *obj* values. 
+    r"""DTLZ3 multiobjective function. It returns a tuple of *obj* values.
     The individual must have at least *obj* elements.
-    From: K. Deb, L. Thiele, M. Laumanns and E. Zitzler. Scalable Multi-Objective 
+    From: K. Deb, L. Thiele, M. Laumanns and E. Zitzler. Scalable Multi-Objective
     Optimization Test Problems. CEC 2002, p. 825 - 830, IEEE Press, 2002.
-    
-    :math:`g(\\mathbf{x}_m) = 100\\left(|\\mathbf{x}_m| + \sum_{x_i \in \\mathbf{x}_m}\\left((x_i - 0.5)^2 - \\cos(20\pi(x_i - 0.5))\\right)\\right)`
-    
-    :math:`f_{\\text{DTLZ3}1}(\\mathbf{x}) = (1 + g(\\mathbf{x}_m)) \\prod_{i=1}^{m-1} \\cos(0.5x_i\pi)`
-    
-    :math:`f_{\\text{DTLZ3}2}(\\mathbf{x}) = (1 + g(\\mathbf{x}_m)) \\sin(0.5x_{m-1}\pi ) \\prod_{i=1}^{m-2} \\cos(0.5x_i\pi)`
-    
-    :math:`\\ldots`
-    
-    :math:`f_{\\text{DTLZ3}m}(\\mathbf{x}) = (1 + g(\\mathbf{x}_m)) \\sin(0.5x_{1}\pi )`
-    
-    Where :math:`m` is the number of objectives and :math:`\\mathbf{x}_m` is a
-    vector of the remaining attributes :math:`[x_m~\\ldots~x_n]` of the
+
+    :math:`g(\mathbf{x}_m) = 100\left(|\mathbf{x}_m| + \sum_{x_i \in \mathbf{x}_m}\left((x_i - 0.5)^2 - \cos(20\pi(x_i - 0.5))\right)\right)`
+
+    :math:`f_{\text{DTLZ3}1}(\mathbf{x}) = (1 + g(\mathbf{x}_m)) \prod_{i=1}^{m-1} \cos(0.5x_i\pi)`
+
+    :math:`f_{\text{DTLZ3}2}(\mathbf{x}) = (1 + g(\mathbf{x}_m)) \sin(0.5x_{m-1}\pi ) \prod_{i=1}^{m-2} \cos(0.5x_i\pi)`
+
+    :math:`\ldots`
+
+    :math:`f_{\text{DTLZ3}m}(\mathbf{x}) = (1 + g(\mathbf{x}_m)) \sin(0.5x_{1}\pi )`
+
+    Where :math:`m` is the number of objectives and :math:`\mathbf{x}_m` is a
+    vector of the remaining attributes :math:`[x_m~\ldots~x_n]` of the
     individual in :math:`n > m` dimensions.
     """
     xc = individual[:obj-1]
@@ -548,25 +548,25 @@ def dtlz3(individual, obj):
     return f
 
 def dtlz4(individual, obj, alpha):
-    """DTLZ4 multiobjective function. It returns a tuple of *obj* values. The
+    r"""DTLZ4 multiobjective function. It returns a tuple of *obj* values. The
     individual must have at least *obj* elements. The *alpha* parameter allows
-    for a meta-variable mapping in :func:`dtlz2` :math:`x_i \\rightarrow
-    x_i^\\alpha`, the authors suggest :math:`\\alpha = 100`.
-    From: K. Deb, L. Thiele, M. Laumanns and E. Zitzler. Scalable Multi-Objective 
+    for a meta-variable mapping in :func:`dtlz2` :math:`x_i \rightarrow
+    x_i^\alpha`, the authors suggest :math:`\alpha = 100`.
+    From: K. Deb, L. Thiele, M. Laumanns and E. Zitzler. Scalable Multi-Objective
     Optimization Test Problems. CEC 2002, p. 825 - 830, IEEE Press, 2002.
-    
-    :math:`g(\\mathbf{x}_m) = \\sum_{x_i \in \\mathbf{x}_m} (x_i - 0.5)^2`
-    
-    :math:`f_{\\text{DTLZ4}1}(\\mathbf{x}) = (1 + g(\\mathbf{x}_m)) \\prod_{i=1}^{m-1} \\cos(0.5x_i^\\alpha\pi)`
-    
-    :math:`f_{\\text{DTLZ4}2}(\\mathbf{x}) = (1 + g(\\mathbf{x}_m)) \\sin(0.5x_{m-1}^\\alpha\pi ) \\prod_{i=1}^{m-2} \\cos(0.5x_i^\\alpha\pi)`
-    
-    :math:`\\ldots`
-    
-    :math:`f_{\\text{DTLZ4}m}(\\mathbf{x}) = (1 + g(\\mathbf{x}_m)) \\sin(0.5x_{1}^\\alpha\pi )`
-    
-    Where :math:`m` is the number of objectives and :math:`\\mathbf{x}_m` is a
-    vector of the remaining attributes :math:`[x_m~\\ldots~x_n]` of the
+
+    :math:`g(\mathbf{x}_m) = \sum_{x_i \in \mathbf{x}_m} (x_i - 0.5)^2`
+
+    :math:`f_{\text{DTLZ4}1}(\mathbf{x}) = (1 + g(\mathbf{x}_m)) \prod_{i=1}^{m-1} \cos(0.5x_i^\alpha\pi)`
+
+    :math:`f_{\text{DTLZ4}2}(\mathbf{x}) = (1 + g(\mathbf{x}_m)) \sin(0.5x_{m-1}^\alpha\pi ) \prod_{i=1}^{m-2} \cos(0.5x_i^\alpha\pi)`
+
+    :math:`\ldots`
+
+    :math:`f_{\text{DTLZ4}m}(\mathbf{x}) = (1 + g(\mathbf{x}_m)) \sin(0.5x_{1}^\alpha\pi )`
+
+    Where :math:`m` is the number of objectives and :math:`\mathbf{x}_m` is a
+    vector of the remaining attributes :math:`[x_m~\ldots~x_n]` of the
     individual in :math:`n > m` dimensions.
     """
     xc = individual[:obj-1]
@@ -577,17 +577,17 @@ def dtlz4(individual, obj, alpha):
     return f
 
 def dtlz5(ind, n_objs):
-    """DTLZ5 multiobjective function. It returns a tuple of *obj* values. The
+    r"""DTLZ5 multiobjective function. It returns a tuple of *obj* values. The
     individual must have at least *obj* elements.
     From: K. Deb, L. Thiele, M. Laumanns and E. Zitzler. Scalable Multi-Objective
     Optimization Test Problems. CEC 2002, p. 825-830, IEEE Press, 2002.
     """
     g = lambda x: sum([(a - 0.5)**2 for a in x])
     gval = g(ind[n_objs-1:])
-    
+
     theta = lambda x: pi / (4.0 * (1 + gval)) * (1 + 2 * gval * x)
     fit = [(1 + gval) * cos(pi / 2.0 * ind[0]) * reduce(lambda x,y: x*y, [cos(theta(a)) for a in ind[1:]])]
-           
+
     for m in reversed(range(1, n_objs)):
         if m == 1:
             fit.append((1 + gval) * sin(pi / 2.0 * ind[0]))
@@ -597,14 +597,14 @@ def dtlz5(ind, n_objs):
     return fit
 
 def dtlz6(ind, n_objs):
-    """DTLZ6 multiobjective function. It returns a tuple of *obj* values. The
+    r"""DTLZ6 multiobjective function. It returns a tuple of *obj* values. The
     individual must have at least *obj* elements.
     From: K. Deb, L. Thiele, M. Laumanns and E. Zitzler. Scalable Multi-Objective
     Optimization Test Problems. CEC 2002, p. 825-830, IEEE Press, 2002.
     """
     gval = sum([a**0.1 for a in ind[n_objs-1:]])
     theta = lambda x: pi / (4.0 * (1 + gval)) * (1 + 2 * gval * x)
-    
+
     fit = [(1 + gval) * cos(pi / 2.0 * ind[0]) *
            reduce(lambda x,y: x*y, [cos(theta(a)) for a in ind[1:]])]
 
@@ -617,7 +617,7 @@ def dtlz6(ind, n_objs):
     return fit
 
 def dtlz7(ind, n_objs):
-    """DTLZ7 multiobjective function. It returns a tuple of *obj* values. The
+    r"""DTLZ7 multiobjective function. It returns a tuple of *obj* values. The
     individual must have at least *obj* elements.
     From: K. Deb, L. Thiele, M. Laumanns and E. Zitzler. Scalable Multi-Objective
     Optimization Test Problems. CEC 2002, p. 825-830, IEEE Press, 2002.
@@ -628,36 +628,36 @@ def dtlz7(ind, n_objs):
     return fit
 
 def fonseca(individual):
-    """Fonseca and Fleming's multiobjective function.
+    r"""Fonseca and Fleming's multiobjective function.
     From: C. M. Fonseca and P. J. Fleming, "Multiobjective optimization and
     multiple constraint handling with evolutionary algorithms -- Part II:
     Application example", IEEE Transactions on Systems, Man and Cybernetics,
     1998.
-    
-    :math:`f_{\\text{Fonseca}1}(\\mathbf{x}) = 1 - e^{-\\sum_{i=1}^{3}(x_i - \\frac{1}{\\sqrt{3}})^2}`
-    
-    :math:`f_{\\text{Fonseca}2}(\\mathbf{x}) = 1 - e^{-\\sum_{i=1}^{3}(x_i + \\frac{1}{\\sqrt{3}})^2}`
+
+    :math:`f_{\text{Fonseca}1}(\mathbf{x}) = 1 - e^{-\sum_{i=1}^{3}(x_i - \frac{1}{\sqrt{3}})^2}`
+
+    :math:`f_{\text{Fonseca}2}(\mathbf{x}) = 1 - e^{-\sum_{i=1}^{3}(x_i + \frac{1}{\sqrt{3}})^2}`
     """
     f_1 = 1 - exp(-sum((xi - 1/sqrt(3))**2 for xi in individual[:3]))
     f_2 = 1 - exp(-sum((xi + 1/sqrt(3))**2 for xi in individual[:3]))
     return f_1, f_2
 
 def poloni(individual):
-    """Poloni's multiobjective function on a two attribute *individual*. From:
+    r"""Poloni's multiobjective function on a two attribute *individual*. From:
     C. Poloni, "Hybrid GA for multi objective aerodynamic shape optimization",
     in Genetic Algorithms in Engineering and Computer Science, 1997.
-    
-    :math:`A_1 = 0.5 \\sin (1) - 2 \\cos (1) + \\sin (2) - 1.5 \\cos (2)`
 
-    :math:`A_2 = 1.5 \\sin (1) - \\cos (1) + 2 \\sin (2) - 0.5 \\cos (2)`
+    :math:`A_1 = 0.5 \sin (1) - 2 \cos (1) + \sin (2) - 1.5 \cos (2)`
 
-    :math:`B_1 = 0.5 \\sin (x_1) - 2 \\cos (x_1) + \\sin (x_2) - 1.5 \\cos (x_2)`
+    :math:`A_2 = 1.5 \sin (1) - \cos (1) + 2 \sin (2) - 0.5 \cos (2)`
 
-    :math:`B_2 = 1.5 \\sin (x_1) - cos(x_1) + 2 \\sin (x_2) - 0.5 \\cos (x_2)`
-    
-    :math:`f_{\\text{Poloni}1}(\\mathbf{x}) = 1 + (A_1 - B_1)^2 + (A_2 - B_2)^2`
-    
-    :math:`f_{\\text{Poloni}2}(\\mathbf{x}) = (x_1 + 3)^2 + (x_2 + 1)^2`
+    :math:`B_1 = 0.5 \sin (x_1) - 2 \cos (x_1) + \sin (x_2) - 1.5 \cos (x_2)`
+
+    :math:`B_2 = 1.5 \sin (x_1) - cos(x_1) + 2 \sin (x_2) - 0.5 \cos (x_2)`
+
+    :math:`f_{\text{Poloni}1}(\mathbf{x}) = 1 + (A_1 - B_1)^2 + (A_2 - B_2)^2`
+
+    :math:`f_{\text{Poloni}2}(\mathbf{x}) = (x_1 + 3)^2 + (x_2 + 1)^2`
     """
     x_1 = individual[0]
     x_2 = individual[1]
@@ -668,7 +668,7 @@ def poloni(individual):
     return 1 + (A_1 - B_1)**2 + (A_2 - B_2)**2, (x_1 + 3)**2 + (x_2 + 1)**2
 
 def dent(individual, lambda_ = 0.85):
-    """Test problem Dent. Two-objective problem with a "dent". *individual* has
+    r"""Test problem Dent. Two-objective problem with a "dent". *individual* has
     two attributes that take values in [-1.5, 1.5].
     From: Schuetze, O., Laumanns, M., Tantar, E., Coello Coello, C.A., & Talbi, E.-G. (2010).
     Computing gap free Pareto front approximations with stochastic search algorithms.
@@ -678,11 +678,10 @@ def dent(individual, lambda_ = 0.85):
     K. Witting and M. Hessel von Molo. Private communication, 2006.
     """
     d = lambda_ * exp(-(individual[0] - individual[1]) ** 2)
-    f1 = 0.5 * (sqrt(1 + (individual[0] + individual[1]) ** 2) + \
-                sqrt(1 + (individual[0] - individual[1]) ** 2) + \
+    f1 = 0.5 * (sqrt(1 + (individual[0] + individual[1]) ** 2) +
+                sqrt(1 + (individual[0] - individual[1]) ** 2) +
                 individual[0] - individual[1]) + d
-    f2 = 0.5 * (sqrt(1 + (individual[0] + individual[1]) ** 2) + \
-                sqrt(1 + (individual[0] - individual[1]) ** 2) - \
+    f2 = 0.5 * (sqrt(1 + (individual[0] + individual[1]) ** 2) +
+                sqrt(1 + (individual[0] - individual[1]) ** 2) -
                 individual[0] + individual[1]) + d
     return f1, f2
-
