@@ -5,13 +5,15 @@ from functools import wraps
 from itertools import repeat
 try:
     import numpy
+    numpy_imported = True
 except ImportError:
-    numpy = False
+    numpy_imported = False
 
 try:
-    from scipy.spatial import distance
+    import scipy.spatial
+    scipy_imported = True
 except ImportError:
-    scipy = False
+    scipy_imported = False
 
 try:
     # try importing the C version
@@ -79,7 +81,7 @@ class rotate(object):
            Q, _ = numpy.linalg.qr(A)
     """
     def __init__(self, matrix):
-        if not numpy:
+        if not numpy_imported:
             raise RuntimeError("Numpy is required for using the rotation "
                 "decorator")
         # The inverse is taken since the rotation is applied to the individual
@@ -178,7 +180,7 @@ class scale(object):
     This decorator adds a :func:`scale` method to the decorated function.
     """
     def __init__(self, factor):
-        # Factor is inverted since it is aplied to the individual and not the
+        # Factor is inverted since it is applied to the individual and not the
         # objective function
         self.factor = tuple(1.0/f for f in factor)
 
@@ -203,7 +205,7 @@ class scale(object):
             # This will cancel the scaling
             evaluate.scale([1.0, 1.0, ..., 1.0])
         """
-        # Factor is inverted since it is aplied to the individual and not the
+        # Factor is inverted since it is applied to the individual and not the
         # objective function
         self.factor = tuple(1.0/f for f in factor)
 
@@ -211,7 +213,7 @@ class bound(object):
     """Decorator for crossover and mutation functions, it changes the
     individuals after the modification is done to bring it back in the allowed
     *bounds*. The *bounds* are functions taking individual and returning
-    wheter of not the variable is allowed. You can provide one or multiple such
+    whether of not the variable is allowed. You can provide one or multiple such
     functions. In the former case, the function is used on all dimensions and
     in the latter case, the number of functions must be greater or equal to
     the number of dimension of the individuals.
@@ -285,7 +287,7 @@ def convergence(first_front, optimal_front):
         distances.append(float("inf"))
         for opt_ind in optimal_front:
             dist = 0.
-            for i in xrange(len(opt_ind)):
+            for i in range(len(opt_ind)):
                 dist += (ind.fitness.values[i] - opt_ind[i])**2
             if dist < distances[-1]:
                 distances[-1] = dist
@@ -312,7 +314,7 @@ def hypervolume(front, ref=None):
 def igd(A, Z):
     """Inverse generational distance.
     """
-    if not scipy:
+    if not scipy_imported:
         raise ImportError("idg requires scipy module")
-    distances = distance.cdist(A, Z)
+    distances = scipy.spatial.distance.cdist(A, Z)
     return numpy.average(numpy.min(distances, axis=0))
