@@ -61,7 +61,7 @@ else:
         @staticmethod
         def __new__(cls, iterable):
             """Creates a new instance of a numpy.ndarray from a function call.
-            Adds the possibility to instanciate from an iterable."""
+            Adds the possibility to instantiate from an iterable."""
             return numpy.array(list(iterable)).view(cls)
 
         def __setstate__(self, state):
@@ -142,7 +142,7 @@ def create(name, base, **kargs):
 
     dict_inst = {}
     dict_cls = {}
-    for obj_name, obj in kargs.iteritems():
+    for obj_name, obj in kargs.items():
         if isinstance(obj, type):
             dict_inst[obj_name] = obj
         else:
@@ -161,7 +161,7 @@ def create(name, base, **kargs):
         """Replace the __init__ function of the new type, in order to
         add attributes that were defined with **kargs to the instance.
         """
-        for obj_name, obj in dict_inst.iteritems():
+        for obj_name, obj in dict_inst.items():
             setattr(self, obj_name, obj())
         if base.__init__ is not object.__init__:
             base.__init__(self, *args, **kargs)
