@@ -1,4 +1,3 @@
-from __future__ import division
 import bisect
 from collections import defaultdict, namedtuple
 from itertools import chain
@@ -74,7 +73,7 @@ def sortNondominated(individuals, k, first_front_only=False):
     map_fit_ind = defaultdict(list)
     for ind in individuals:
         map_fit_ind[ind.fitness].append(ind)
-    fits = map_fit_ind.keys()
+    fits = list(map_fit_ind.keys())
 
     current_front = []
     next_front = []
@@ -129,7 +128,7 @@ def assignCrowdingDist(individuals):
 
     nobj = len(individuals[0].fitness.values)
 
-    for i in xrange(nobj):
+    for i in range(nobj):
         crowd.sort(key=lambda element: element[0][i])
         distances[crowd[0][1]] = float("inf")
         distances[crowd[-1][1]] = float("inf")
@@ -146,24 +145,26 @@ def selTournamentDCD(individuals, k):
     """Tournament selection based on dominance (D) between two individuals, if
     the two individuals do not interdominate the selection is made
     based on crowding distance (CD). The *individuals* sequence length has to
-    be a multiple of 4. Starting from the beginning of the selected
-    individuals, two consecutive individuals will be different (assuming all
-    individuals in the input list are unique). Each individual from the input
-    list won't be selected more than twice.
+    be a multiple of 4 only if k is equal to the length of individuals. 
+    Starting from the beginning of the selected individuals, two consecutive 
+    individuals will be different (assuming all individuals in the input list 
+    are unique). Each individual from the input list won't be selected more 
+    than twice.
 
     This selection requires the individuals to have a :attr:`crowding_dist`
     attribute, which can be set by the :func:`assignCrowdingDist` function.
 
     :param individuals: A list of individuals to select from.
-    :param k: The number of individuals to select.
+    :param k: The number of individuals to select. Must be less than or equal 
+              to len(individuals).
     :returns: A list of selected individuals.
     """
 
-    if len(individuals) % 4 != 0:
-        raise ValueError("selTournamentDCD: individuals length must be a multiple of 4")
+    if k > len(individuals): 
+        raise ValueError("selTournamentDCD: k must be less than or equal to individuals length")
 
-    if k % 4 != 0:
-        raise ValueError("selTournamentDCD: number of individuals to select must be a multiple of 4")
+    if k == len(individuals) and k % 4 != 0:
+        raise ValueError("selTournamentDCD: k must be divisible by four if k == len(individuals)")
 
     def tourn(ind1, ind2):
         if ind1.fitness.dominates(ind2.fitness):
@@ -184,7 +185,7 @@ def selTournamentDCD(individuals, k):
     individuals_2 = random.sample(individuals, len(individuals))
 
     chosen = []
-    for i in xrange(0, k, 4):
+    for i in range(0, k, 4):
         chosen.append(tourn(individuals_1[i],   individuals_1[i+1]))
         chosen.append(tourn(individuals_1[i+2], individuals_1[i+3]))
         chosen.append(tourn(individuals_2[i],   individuals_2[i+1]))
@@ -202,7 +203,7 @@ def identity(obj):
     return obj
 
 def isDominated(wvalues1, wvalues2):
-    """Returns whether or not *wvalues1* dominates *wvalues2*.
+    """Returns whether or not *wvalues2* dominates *wvalues1*.
 
     :param wvalues1: The weighted fitness values that would be dominated.
     :param wvalues2: The weighted fitness values of the dominant.
@@ -248,7 +249,7 @@ def sortLogNondominated(individuals, k, first_front_only=False):
 
     #Launch the sorting algorithm
     obj = len(individuals[0].fitness.wvalues)-1
-    fitnesses = unique_fits.keys()
+    fitnesses = list(unique_fits.keys())
     front = dict.fromkeys(fitnesses, 0)
 
     # Sort the fitnesses lexicographically.
@@ -448,7 +449,7 @@ NSGA3Memory = namedtuple("NSGA3Memory", ["best_point", "worst_point", "extreme_p
 class selNSGA3WithMemory(object):
     """Class version of NSGA-III selection including memory for best, worst and
     extreme points. Registering this operator in a toolbox is a bit different
-    than classical operators, it requires to instanciate the class instead
+    than classical operators, it requires to instantiate the class instead
     of just registering the function::
 
         >>> from deap import base
@@ -589,12 +590,15 @@ def find_intercepts(extreme_points, best_point, current_worst, front_worst):
     except numpy.linalg.LinAlgError:
         intercepts = current_worst
     else:
-        intercepts = 1 / x
-
-        if (not numpy.allclose(numpy.dot(A, x), b) or
-                numpy.any(intercepts <= 1e-6) or
-                numpy.any((intercepts + best_point) > current_worst)):
+        if numpy.count_nonzero(x) != len(x):
             intercepts = front_worst
+        else:
+            intercepts = 1 / x
+
+            if (not numpy.allclose(numpy.dot(A, x), b) or
+                    numpy.any(intercepts <= 1e-6) or
+                    numpy.any((intercepts + best_point) > current_worst)):
+                intercepts = front_worst
 
     return intercepts
 
@@ -615,19 +619,19 @@ def associate_to_niche(fitnesses, reference_points, best_point, intercepts):
 
     # Retrieve min distance niche index
     niches = numpy.argmin(distances, axis=1)
-    distances = distances[range(niches.shape[0]), niches]
+    distances = distances[list(range(niches.shape[0])), niches]
     return niches, distances
 
 
 def niching(individuals, k, niches, distances, niche_counts):
     selected = []
-    available = numpy.ones(len(individuals), dtype=numpy.bool)
+    available = numpy.ones(len(individuals), dtype=bool)
     while len(selected) < k:
         # Maximum number of individuals (niches) to select in that round
         n = k - len(selected)
 
         # Find the available niches and the minimum niche count in them
-        available_niches = numpy.zeros(len(niche_counts), dtype=numpy.bool)
+        available_niches = numpy.zeros(len(niche_counts), dtype=bool)
         available_niches[numpy.unique(niches[available])] = True
         min_count = numpy.min(niche_counts[available_niches])
 
@@ -637,8 +641,8 @@ def niching(individuals, k, niches, distances, niche_counts):
         selected_niches = selected_niches[:n]
 
         for niche in selected_niches:
-            # Find the individuals associated with this niche
-            niche_individuals = numpy.flatnonzero(niches == niche)
+            # Select from available individuals in niche
+            niche_individuals = numpy.flatnonzero(numpy.logical_and(niches == niche, available))
             numpy.random.shuffle(niche_individuals)
 
             # If no individual in that niche, select the closest to reference
@@ -705,7 +709,7 @@ def selSPEA2(individuals, k):
     K = math.sqrt(N)
     strength_fits = [0] * N
     fits = [0] * N
-    dominating_inds = [list() for i in xrange(N)]
+    dominating_inds = [list() for i in range(N)]
 
     for i, ind_i in enumerate(individuals):
         for j, ind_j in enumerate(individuals[i+1:], i+1):
@@ -716,19 +720,19 @@ def selSPEA2(individuals, k):
                 strength_fits[j] += 1
                 dominating_inds[i].append(j)
 
-    for i in xrange(N):
+    for i in range(N):
         for j in dominating_inds[i]:
             fits[i] += strength_fits[j]
 
     # Choose all non-dominated individuals
-    chosen_indices = [i for i in xrange(N) if fits[i] < 1]
+    chosen_indices = [i for i in range(N) if fits[i] < 1]
 
     if len(chosen_indices) < k:     # The archive is too small
-        for i in xrange(N):
+        for i in range(N):
             distances = [0.0] * N
-            for j in xrange(i + 1, N):
+            for j in range(i + 1, N):
                 dist = 0.0
-                for l in xrange(L):
+                for l in range(L):
                     val = individuals[i].fitness.values[l] - \
                           individuals[j].fitness.values[l]
                     dist += val * val
@@ -737,7 +741,7 @@ def selSPEA2(individuals, k):
             density = 1.0 / (kth_dist + 2.0)
             fits[i] += density
 
-        next_indices = [(fits[i], i) for i in xrange(N)
+        next_indices = [(fits[i], i) for i in range(N)
                         if not i in chosen_indices]
         next_indices.sort()
         #print next_indices
@@ -745,12 +749,12 @@ def selSPEA2(individuals, k):
 
     elif len(chosen_indices) > k:   # The archive is too large
         N = len(chosen_indices)
-        distances = [[0.0] * N for i in xrange(N)]
-        sorted_indices = [[0] * N for i in xrange(N)]
-        for i in xrange(N):
-            for j in xrange(i + 1, N):
+        distances = [[0.0] * N for i in range(N)]
+        sorted_indices = [[0] * N for i in range(N)]
+        for i in range(N):
+            for j in range(i + 1, N):
                 dist = 0.0
-                for l in xrange(L):
+                for l in range(L):
                     val = individuals[chosen_indices[i]].fitness.values[l] - \
                           individuals[chosen_indices[j]].fitness.values[l]
                     dist += val * val
@@ -759,8 +763,8 @@ def selSPEA2(individuals, k):
             distances[i][i] = -1
 
         # Insert sort is faster than quick sort for short arrays
-        for i in xrange(N):
-            for j in xrange(1, N):
+        for i in range(N):
+            for j in range(1, N):
                 l = j
                 while l > 0 and distances[i][j] < distances[i][sorted_indices[i][l - 1]]:
                     sorted_indices[i][l] = sorted_indices[i][l - 1]
@@ -772,8 +776,8 @@ def selSPEA2(individuals, k):
         while size > k:
             # Search for minimal distance
             min_pos = 0
-            for i in xrange(1, N):
-                for j in xrange(1, size):
+            for i in range(1, N):
+                for j in range(1, size):
                     dist_i_sorted_j = distances[i][sorted_indices[i][j]]
                     dist_min_sorted_j = distances[min_pos][sorted_indices[min_pos][j]]
 
@@ -784,11 +788,11 @@ def selSPEA2(individuals, k):
                         break
 
             # Remove minimal distance from sorted_indices
-            for i in xrange(N):
+            for i in range(N):
                 distances[i][min_pos] = float("inf")
                 distances[min_pos][i] = float("inf")
 
-                for j in xrange(1, size - 1):
+                for j in range(1, size - 1):
                     if sorted_indices[i][j] == min_pos:
                         sorted_indices[i][j] = sorted_indices[i][j + 1]
                         sorted_indices[i][j + 1] = min_pos
