@@ -1,6 +1,3 @@
-from __future__ import division
-
-
 def migRing(populations, k, selection, replacement=None, migarray=None):
     """Perform a ring migration between the *populations*. The migration first
     select *k* emigrants from each population using the specified *selection*
@@ -31,12 +28,12 @@ def migRing(populations, k, selection, replacement=None, migarray=None):
     """
     nbr_demes = len(populations)
     if migarray is None:
-        migarray = range(1, nbr_demes) + [0]
+        migarray = list(range(1, nbr_demes)) + [0]
 
-    immigrants = [[] for i in xrange(nbr_demes)]
-    emigrants = [[] for i in xrange(nbr_demes)]
+    immigrants = [[] for i in range(nbr_demes)]
+    emigrants = [[] for i in range(nbr_demes)]
 
-    for from_deme in xrange(nbr_demes):
+    for from_deme in range(nbr_demes):
         emigrants[from_deme].extend(selection(populations[from_deme], k))
         if replacement is None:
             # If no replacement strategy is selected, replace those who migrate
@@ -50,4 +47,4 @@ def migRing(populations, k, selection, replacement=None, migarray=None):
             indx = populations[to_deme].index(immigrant)
             populations[to_deme][indx] = emigrants[from_deme][i]
 
-__all__ = ['migRing']
\ No newline at end of file
+__all__ = ['migRing']
